==> eiffelstudio-18.07.10.1981.tar: F_code/C4/cl180.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl180.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F219_2869 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1005, 0x01).id, 1005, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F997_7562(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F219_2870 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	F219_2871(Current);
	Result = '\0';
	if (F219_2885(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F219_2871 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	F219_2889(Current);
	F219_2890(Current);
	F219_2872(Current);
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F219_2872 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		F219_2890(Current);
		F219_2873(Current);
	} else {
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F219_2873 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		F219_2890(Current);
		F219_2872(Current);
		F219_2874(Current);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F219_2874 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		F219_2890(Current);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			F219_2890(Current);
			F219_2872(Current);
			F219_2874(Current);
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.current_parsed_string */
EIF_REFERENCE F219_2883 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F219_2885 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6452[Dtype(tr1)-998])(RTCW(tr1));
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F219_2888 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F219_2889 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F219_2885(Current)) {
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6416[Dtype(tr1)-999])(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F219_2890 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tb2 = EIF_TEST(isspace(tw1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F219_2888(Current);
			}
			if (tb1) break;
			F219_2889(Current);
		}
		if ((EIF_BOOLEAN) !F219_2888(Current)) {
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					F219_2889(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					F219_2889(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					F219_2889(Current);
					break;
				default:
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(953, 0x00).id, 953, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F952_7442(RTCW(tr1));
					if (tb2) {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						tr1 = RTLNS(eif_new_type(1005, 0x01).id, 1005, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1004_7855(RTCW(tr1), ((EIF_INTEGER_32) 20L));
						loc1 = (EIF_REFERENCE) tr1;
						for (;;) {
							tb2 = '\01';
							if (!F219_2888(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(953, 0x00).id, 953, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F952_7450(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							F1006_7982(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							F219_2889(Current);
						}
						tr1 = RTOSCF(2857,F218_2857,(Current));
						tr2 = F1006_8002(RTCW(loc1));
						tb3 = F770_6006(RTCW(tr1), tr2);
						if (tb3) {
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTLE;
}

void EIF_Minit180 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C4/cl180.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl180.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F220_2763 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1017_7422(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F220_2764 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	F220_2765(Current);
	Result = '\0';
	if (F220_2779(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F220_2765 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	F220_2783(Current);
	F220_2784(Current);
	F220_2766(Current);
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F220_2766 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		F220_2784(Current);
		F220_2767(Current);
	} else {
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F220_2767 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		F220_2784(Current);
		F220_2766(Current);
		F220_2768(Current);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F220_2768 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		F220_2784(Current);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			F220_2784(Current);
			F220_2766(Current);
			F220_2768(Current);
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F220_2779 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6382[Dtype(RTCW(tr1))-1019])(tr1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F220_2782 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F220_2783 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F220_2779(Current)) {
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R6346[Dtype(RTCW(tr1))-1019])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F220_2784 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tb2 = EIF_TEST(isspace(tw1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F220_2782(Current);
			}
			if (tb1) break;
			F220_2783(Current);
		}
		if ((EIF_BOOLEAN) !F220_2782(Current)) {
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					F220_2783(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					F220_2783(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					F220_2783(Current);
					break;
				default:
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(970, 0x00).id, 970, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F969_7255(RTCW(tr1));
					if (tb2) {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						loc1 = RTLNS(eif_new_type(1026, 0x00).id, 1026, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1025_7718(RTCW(loc1), ((EIF_INTEGER_32) 20L));
						for (;;) {
							tb2 = '\01';
							if (!F220_2782(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(970, 0x00).id, 970, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F969_7263(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							F1027_7845(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							F220_2783(Current);
						}
						tr1 = RTOSCF(2751,F219_2751, (Current));
						tr2 = F1027_7865(RTCW(loc1));
						tb3 = F768_5754(RTCW(tr1), tr2);
						if (tb3) {
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTLE;
}

void EIF_Minit180 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
